@@ -37,38 +37,33 @@ macro_rules! config_struct {
 optional_config_struct!(
     ConfigKeymap,
     clear,
-    force_redraw,
-    delete_deny,
     delete_confirm,
+    delete_deny,
     exec,
     filter_mode,
-    log_section_height_increase,
-    log_section_height_decrease,
-    log_section_toggle,
-    log_scroll_forward,
+    force_redraw,
     log_scroll_back,
+    log_scroll_forward,
+    log_search_mode,
+    log_section_height_decrease,
+    log_section_height_increase,
+    log_section_toggle,
     quit,
     save_logs,
-    // TODO remove in next release
-    scroll_down_many,
-    // TODO rename in next release
-    scroll_down_one,
+    scroll_down,
     scroll_end,
     scroll_start,
-    // TODO remove in next release
-    scroll_up_many,
-    // TODO rename in next release
-    scroll_up_one,
+    scroll_up,
     select_next_panel,
     select_previous_panel,
-    sort_by_name,
-    sort_by_state,
-    sort_by_status,
     sort_by_cpu,
-    sort_by_memory,
     sort_by_id,
     sort_by_image,
+    sort_by_memory,
+    sort_by_name,
     sort_by_rx,
+    sort_by_state,
+    sort_by_status,
     sort_by_tx,
     sort_reset,
     toggle_help,
@@ -78,38 +73,33 @@ optional_config_struct!(
 config_struct!(
     Keymap,
     clear,
-    delete_deny,
     delete_confirm,
+    delete_deny,
     exec,
     filter_mode,
     force_redraw,
-    log_section_height_increase,
-    log_section_height_decrease,
-    log_section_toggle,
-    log_scroll_forward,
     log_scroll_back,
+    log_scroll_forward,
+    log_search_mode,
+    log_section_height_decrease,
+    log_section_height_increase,
+    log_section_toggle,
     quit,
     save_logs,
-    // TODO remove in next release
-    scroll_down_many,
-    // TODO rename in next release
-    scroll_down_one,
+    scroll_down,
     scroll_end,
     scroll_start,
-    // TODO remove in next release
-    scroll_up_many,
-    // TODO rename in next release
-    scroll_up_one,
+    scroll_up,
     select_next_panel,
     select_previous_panel,
-    sort_by_name,
-    sort_by_state,
-    sort_by_status,
     sort_by_cpu,
-    sort_by_memory,
     sort_by_id,
     sort_by_image,
+    sort_by_memory,
+    sort_by_name,
     sort_by_rx,
+    sort_by_state,
+    sort_by_status,
     sort_by_tx,
     sort_reset,
     toggle_help,
@@ -125,24 +115,19 @@ impl Keymap {
             exec: (KeyCode::Char('e'), None),
             filter_mode: (KeyCode::Char('/'), Some(KeyCode::F(1))),
             force_redraw: (KeyCode::Char('f'), None),
+            log_scroll_back: (KeyCode::Left, None),
+            log_scroll_forward: (KeyCode::Right, None),
+            log_search_mode: (KeyCode::Char('#'), None),
             log_section_height_decrease: (KeyCode::Char('-'), None),
             log_section_height_increase: (KeyCode::Char('='), None),
             log_section_toggle: (KeyCode::Char('\\'), None),
-            log_scroll_back: (KeyCode::Left, None),
-            log_scroll_forward: (KeyCode::Right, None),
             quit: (KeyCode::Char('q'), None),
             save_logs: (KeyCode::Char('s'), None),
-            // TODO remove in next release
-            scroll_down_many: (KeyCode::PageDown, None),
-            // TODO rename in next release
-            scroll_down_one: (KeyCode::Down, Some(KeyCode::Char('j'))),
+            scroll_down: (KeyCode::Down, Some(KeyCode::Char('j'))),
             scroll_end: (KeyCode::End, None),
-            scroll_start: (KeyCode::Home, None),
             scroll_many: KeyModifiers::CONTROL,
-            // TODO remove in next release
-            scroll_up_many: (KeyCode::PageUp, None),
-            // TODO rename in next release
-            scroll_up_one: (KeyCode::Up, Some(KeyCode::Char('k'))),
+            scroll_start: (KeyCode::Home, None),
+            scroll_up: (KeyCode::Up, Some(KeyCode::Char('k'))),
             select_next_panel: (KeyCode::Tab, None),
             select_previous_panel: (KeyCode::BackTab, None),
             sort_by_cpu: (KeyCode::Char('4'), None),
@@ -216,16 +201,11 @@ impl From<Option<ConfigKeymap>> for Keymap {
             update_keymap(ck.force_redraw, &mut keymap.force_redraw, &mut clash);
             update_keymap(ck.quit, &mut keymap.quit, &mut clash);
             update_keymap(ck.save_logs, &mut keymap.save_logs, &mut clash);
-            update_keymap(
-                ck.scroll_down_many,
-                &mut keymap.scroll_down_many,
-                &mut clash,
-            );
-            update_keymap(ck.scroll_down_one, &mut keymap.scroll_down_one, &mut clash);
+            update_keymap(ck.scroll_down, &mut keymap.scroll_down, &mut clash);
             update_keymap(ck.scroll_end, &mut keymap.scroll_end, &mut clash);
             update_keymap(ck.scroll_start, &mut keymap.scroll_start, &mut clash);
-            update_keymap(ck.scroll_up_many, &mut keymap.scroll_up_many, &mut clash);
-            update_keymap(ck.scroll_up_one, &mut keymap.scroll_up_one, &mut clash);
+            update_keymap(ck.scroll_up, &mut keymap.scroll_up, &mut clash);
+            update_keymap(ck.log_search_mode, &mut keymap.log_search_mode, &mut clash);
             update_keymap(
                 ck.log_scroll_forward,
                 &mut keymap.log_scroll_forward,
@@ -416,19 +396,18 @@ mod tests {
             filter_mode: None,
             force_redraw: None,
             log_scroll_back: None,
+            log_search_mode: None,
             log_scroll_forward: None,
             log_section_height_decrease: None,
             log_section_height_increase: None,
             log_section_toggle: None,
             quit: None,
             save_logs: None,
-            scroll_down_many: None,
-            scroll_down_one: None,
+            scroll_down: None,
             scroll_end: None,
             scroll_start: None,
             scroll_many: None,
-            scroll_up_many: None,
-            scroll_up_one: None,
+            scroll_up: None,
             select_next_panel: None,
             select_previous_panel: None,
             sort_by_cpu: None,
@@ -458,24 +437,23 @@ mod tests {
         let input = ConfigKeymap {
             clear: gen_v(("a", "b")),
             delete_confirm: gen_v(("c", "d")),
-            delete_deny: gen_v(("e", "fd")),
+            delete_deny: gen_v(("e", "f")),
             exec: gen_v(("g", "h")),
             filter_mode: gen_v(("i", "j")),
             force_redraw: gen_v(("k", "l")),
+            log_scroll_back: gen_v(("s", "t")),
+            log_scroll_forward: gen_v(("q", "r")),
+            log_search_mode: gen_v(("1", "2")),
             log_section_height_decrease: gen_v(("m", "n")),
             log_section_height_increase: gen_v(("o", "p")),
-            log_scroll_forward: gen_v(("q", "r")),
-            log_scroll_back: gen_v(("s", "t")),
             log_section_toggle: gen_v(("u", "v")),
             quit: gen_v(("w", "x")),
             save_logs: gen_v(("y", "z")),
-            scroll_down_many: gen_v(("1", "2")),
-            scroll_down_one: gen_v(("3", "4")),
+            scroll_down: gen_v(("3", "4")),
             scroll_end: gen_v(("5", "6")),
             scroll_many: Some(vec!["alt".to_owned()]),
             scroll_start: gen_v(("7", "8")),
-            scroll_up_many: gen_v(("9", "0")),
-            scroll_up_one: gen_v(("F1", "F2")),
+            scroll_up: gen_v(("F1", "F2")),
             select_next_panel: gen_v(("F3", "F4")),
             select_previous_panel: gen_v(("F5", "F6")),
             sort_by_cpu: gen_v(("F7", "F8")),
@@ -496,39 +474,38 @@ mod tests {
 
         let expected = Keymap {
             clear: (KeyCode::Char('a'), Some(KeyCode::Char('b'))),
-            delete_deny: (KeyCode::Char('e'), None),
             delete_confirm: (KeyCode::Char('c'), Some(KeyCode::Char('d'))),
+            delete_deny: (KeyCode::Char('e'), Some(KeyCode::Char('f'))),
             exec: (KeyCode::Char('g'), Some(KeyCode::Char('h'))),
             filter_mode: (KeyCode::Char('i'), Some(KeyCode::Char('j'))),
             force_redraw: (KeyCode::Char('k'), Some(KeyCode::Char('l'))),
-            log_section_height_increase: (KeyCode::Char('o'), Some(KeyCode::Char('p'))),
-            log_section_height_decrease: (KeyCode::Char('m'), Some(KeyCode::Char('n'))),
-            log_section_toggle: (KeyCode::Char('u'), Some(KeyCode::Char('v'))),
-            log_scroll_forward: (KeyCode::Char('q'), Some(KeyCode::Char('r'))),
             log_scroll_back: (KeyCode::Char('s'), Some(KeyCode::Char('t'))),
+            log_scroll_forward: (KeyCode::Char('q'), Some(KeyCode::Char('r'))),
+            log_search_mode: (KeyCode::Char('1'), Some(KeyCode::Char('2'))),
+            log_section_height_decrease: (KeyCode::Char('m'), Some(KeyCode::Char('n'))),
+            log_section_height_increase: (KeyCode::Char('o'), Some(KeyCode::Char('p'))),
+            log_section_toggle: (KeyCode::Char('u'), Some(KeyCode::Char('v'))),
             quit: (KeyCode::Char('w'), Some(KeyCode::Char('x'))),
             save_logs: (KeyCode::Char('y'), Some(KeyCode::Char('z'))),
-            scroll_down_many: (KeyCode::Char('1'), Some(KeyCode::Char('2'))),
-            scroll_down_one: (KeyCode::Char('3'), Some(KeyCode::Char('4'))),
+            scroll_down: (KeyCode::Char('3'), Some(KeyCode::Char('4'))),
             scroll_end: (KeyCode::Char('5'), Some(KeyCode::Char('6'))),
+            scroll_many: KeyModifiers::ALT,
             scroll_start: (KeyCode::Char('7'), Some(KeyCode::Char('8'))),
-            scroll_up_many: (KeyCode::Char('9'), Some(KeyCode::Char('0'))),
-            scroll_up_one: (KeyCode::F(1), Some(KeyCode::F(2))),
+            scroll_up: (KeyCode::F(1), Some(KeyCode::F(2))),
             select_next_panel: (KeyCode::F(3), Some(KeyCode::F(4))),
             select_previous_panel: (KeyCode::F(5), Some(KeyCode::F(6))),
-            sort_by_name: (KeyCode::Up, Some(KeyCode::Down)),
-            sort_by_state: (KeyCode::Char('['), Some(KeyCode::Char(']'))),
-            sort_by_status: (KeyCode::Tab, None),
             sort_by_cpu: (KeyCode::F(7), Some(KeyCode::F(8))),
-            sort_by_memory: (KeyCode::Home, Some(KeyCode::End)),
             sort_by_id: (KeyCode::F(9), Some(KeyCode::F(10))),
             sort_by_image: (KeyCode::F(11), Some(KeyCode::F(12))),
+            sort_by_memory: (KeyCode::Home, Some(KeyCode::End)),
+            sort_by_name: (KeyCode::Up, Some(KeyCode::Down)),
             sort_by_rx: (KeyCode::Left, Some(KeyCode::Right)),
+            sort_by_state: (KeyCode::Char('['), Some(KeyCode::Char(']'))),
+            sort_by_status: (KeyCode::Tab, None),
             sort_by_tx: (KeyCode::PageDown, Some(KeyCode::PageUp)),
             sort_reset: (KeyCode::Char(','), Some(KeyCode::Char('.'))),
             toggle_help: (KeyCode::Char('-'), Some(KeyCode::Char('='))),
             toggle_mouse_capture: (KeyCode::Char('\\'), Some(KeyCode::Char('/'))),
-            scroll_many: KeyModifiers::ALT,
         };
         assert_eq!(expected, result);
     }
